summaryrefslogtreecommitdiff
path: root/src/cargopacket.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/cargopacket.h')
-rw-r--r--src/cargopacket.h12
1 files changed, 9 insertions, 3 deletions
diff --git a/src/cargopacket.h b/src/cargopacket.h
index 13970e18e..17528e516 100644
--- a/src/cargopacket.h
+++ b/src/cargopacket.h
@@ -57,14 +57,20 @@ public:
static const uint16 MAX_COUNT = UINT16_MAX;
/**
+ * Create a new packet for savegame loading.
+ */
+ CargoPacket();
+
+ /**
* Creates a new cargo packet
* @param source the source of the packet
* @param count the number of cargo entities to put in this packet
* @param source_type the 'type' of source the packet comes from (for subsidies)
* @param source_id the actual source of the packet (for subsidies)
- * @pre count != 0 || source == INVALID_STATION
+ * @pre count != 0
*/
- CargoPacket(StationID source = INVALID_STATION, uint16 count = 0, SourceType source_type = ST_INDUSTRY, SourceID source_id = INVALID_SOURCE);
+ CargoPacket(StationID source, TileIndex source_xy, uint16 count, SourceType source_type, SourceID source_id);
/**
* Creates a new cargo packet. Initializes the fields that cannot be changed later.
@@ -57,14 +57,20 @@ public:
* Creates a new cargo packet
- * @param source the source of the packet
+ * @param source the source station of the packet
+ * @param source_xy the source location of the packet
* @param count the number of cargo entities to put in this packet
* @param source_type the 'type' of source the packet comes from (for subsidies)